@@ -1,4 +1,4 @@
 # Copyright (c) Gorilla-Lab. All rights reserved.
-from . import dann
+from .dann import GradReverse
 
 __all__ = [k for k in globals().keys() if not k.startswith("_")]
